@@ -7,7 +7,7 @@
 # it under the terms of version 2 of the GNU General Public License as
 # published by the Free Software Foundation.
 #
-# $Id: __init__.py 3992 2007-01-27 01:40:51Z piman $
+# $Id: __init__.py 4026 2007-04-27 02:13:05Z piman $
 #
 
 """Mutagen aims to be an all purpose tagging library.
@@ -21,14 +21,14 @@ depending on tag or format. They may also be entirely different objects
 for certain keys, again depending on format.
 """
 
-version = (1, 10, 1)
+version = (1, 11)
 version_string = ".".join(map(str, version))
 
 import warnings
 
 import mutagen._util
 
-class Metadata(dict):
+class Metadata(object):
     """An abstract dict-like object.
 
     Metadata is the base class for many of the tag objects in Mutagen.
