@@ -5,7 +5,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: asf.py 3992 2007-01-27 01:40:51Z piman $
+# $Id: asf.py 4026 2007-04-27 02:13:05Z piman $
 
 """Read and write ASF (Window Media Audio) files."""
 
@@ -35,7 +35,7 @@ class ASFInfo(object):
         return s
 
 
-class ASFTags(list, DictMixin):
+class ASFTags(list, DictMixin, Metadata):
     """Dictionary containing ASF attributes."""
 
     def pprint(self):
