@@ -26,6 +26,7 @@ from cStringIO import StringIO
 from _vorbis import VCommentDict
 from mutagen import FileType
 from mutagen._util import insert_bytes
+from mutagen.id3 import BitPaddedInt
 
 class error(IOError): pass
 class FLACNoHeaderError(error): pass
@@ -403,6 +404,71 @@ class CueSheet(MetadataBlock):
             type(self).__name__, self.media_catalog_number,
             self.lead_in_samples, self.compact_disc, self.tracks)
 
+class Picture(MetadataBlock):
+    """Read and write FLAC embed pictures.
+
+    Attributes:
+    type -- picture type (same as types for ID3 APIC frames)
+    mime -- MIME type of the picture
+    desc -- picture's description
+    width -- width in pixels
+    height -- height in pixels
+    depth -- color depth in bits-per-pixel
+    colors -- number of colors for indexed palettes (like GIF),
+              0 for non-indexed
+    data -- picture data
+    """
+
+    code = 6
+
+    def __init__(self, data=None):
+        self.type = 0
+        self.mime = u''
+        self.desc = u''
+        self.width = 0
+        self.height = 0
+        self.depth = 0
+        self.colors = 0
+        self.data = ''
+        super(Picture, self).__init__(data)
+
+    def __eq__(self, other):
+        try: return (self.type == other.type and
+                     self.mime == other.mime and
+                     self.desc == other.desc and
+                     self.width == other.width and
+                     self.height == other.height and
+                     self.depth == other.depth and
+                     self.colors == other.colors and
+                     self.data == other.data)
+        except (AttributeError, TypeError): return False
+
+    def load(self, data):
+        self.type, length = struct.unpack('>2I', data.read(8))
+        self.mime = data.read(length).decode('UTF-8', 'replace')
+        length, = struct.unpack('>I', data.read(4))
+        self.desc = data.read(length).decode('UTF-8', 'replace')
+        (self.width, self.height, self.depth,
+         self.colors, length) = struct.unpack('>5I', data.read(20))
+        self.data = data.read(length)
+
+    def write(self):
+        f = StringIO()
+        mime = self.mime.encode('UTF-8')
+        f.write(struct.pack('>2I', self.type, len(mime)))
+        f.write(mime)
+        desc = self.desc.encode('UTF-8')
+        f.write(struct.pack('>I', len(desc)))
+        f.write(desc)
+        f.write(struct.pack('>5I', self.width, self.height, self.depth,
+                            self.colors, len(self.data)))
+        f.write(self.data)
+        return f.getvalue()
+
+    def __repr__(self):
+        return "<%s '%s' (%d bytes)>" % (type(self).__name__, self.mime,
+                                         len(self.data))
+
 class Padding(MetadataBlock):
     """Empty padding space for metadata blocks.
 
@@ -423,10 +489,20 @@ class Padding(MetadataBlock):
         return "<%s (%d bytes)>" % (type(self).__name__, self.length)
 
 class FLAC(FileType):
-    """A FLAC audio file."""
+    """A FLAC audio file.
+    
+    Attributes:
+    info -- stream information (length, bitrate, sample rate)
+    tags -- metadata tags, if any
+    cuesheet -- CueSheet object, if any
+    seektable -- SeekTable object, if any
+    pictures -- list of embedded pictures
+    """
+
+    _mimes = ["audio/x-flac", "application/x-flac"]
 
     METADATA_BLOCKS = [StreamInfo, Padding, None, SeekTable, VCFLACDict,
-        CueSheet]
+        CueSheet, Picture]
     """Known metadata block types, indexed by ID."""
 
     def score(filename, fileobj, header):
@@ -489,9 +565,7 @@ class FLAC(FileType):
         self.filename = filename
         try:
             fileobj = file(filename, "rb")
-            if fileobj.read(4) != "fLaC":
-                raise FLACNoHeaderError(
-                    "%r is not a valid FLAC file" % filename)
+            self.__check_header(fileobj)
             while self.__read_metadata_block(fileobj): pass
         finally:
             fileobj.close()
@@ -502,7 +576,20 @@ class FLAC(FileType):
 
     info = property(lambda s: s.metadata_blocks[0])
 
-    def save(self, filename=None):
+    def add_picture(self, picture):
+        """Add a new picture to the file."""
+        self.metadata_blocks.append(picture)
+
+    def clear_pictures(self):
+        """Delete all pictures from the file."""
+        self.metadata_blocks = filter(lambda b: b.code != Picture.code,
+                                      self.metadata_blocks)
+
+    def __get_pictures(self):
+        return filter(lambda b: b.code == Picture.code, self.metadata_blocks)
+    pictures = property(__get_pictures, doc="List of embedded pictures")
+
+    def save(self, filename=None, deleteid3=False):
         """Save metadata blocks to a file.
 
         If no filename is given, the one most recently loaded is used.
@@ -516,9 +603,15 @@ class FLAC(FileType):
         self.metadata_blocks.append(Padding('\x00' * 1020))
         MetadataBlock.group_padding(self.metadata_blocks)
 
-        available = self.__find_audio_offset(f) - 4 # "fLaC"
+        header = self.__check_header(f)
+        available = self.__find_audio_offset(f) - header # "fLaC" and maybe ID3
         data = MetadataBlock.writeblocks(self.metadata_blocks)
 
+        # Delete ID3v2
+        if deleteid3 and header > 4:
+            available += header - 4
+            header = 4
+
         if len(data) > available:
             # If we have too much data, see if we can reduce padding.
             padding = self.metadata_blocks[-1]
@@ -537,14 +630,21 @@ class FLAC(FileType):
         if len(data) != available:
             # We couldn't reduce the padding enough.
             diff = (len(data) - available)
-            insert_bytes(f, diff, 4)
+            insert_bytes(f, diff, header)
 
-        f.seek(4)
-        f.write(data)
+        f.seek(header - 4)
+        f.write("fLaC" + data)
+
+        # Delete ID3v1
+        if deleteid3:
+            try: f.seek(-128, 2)
+            except IOError: pass
+            else:
+                if f.read(3) == "TAG":
+                    f.seek(-128, 2)
+                    f.truncate()
 
     def __find_audio_offset(self, fileobj):
-        if fileobj.read(4) != "fLaC":
-            raise FLACNoHeaderError("%r is not a FLAC file" % fileobj.name)
         byte = 0x00
         while not (byte >> 7) & 1:
             byte = ord(fileobj.read(1))
@@ -552,6 +652,20 @@ class FLAC(FileType):
             fileobj.read(size)
         return fileobj.tell()
 
+    def __check_header(self, fileobj):
+        size = 4
+        header = fileobj.read(4)
+        if header != "fLaC":
+            size = None
+            if header[:3] == "ID3":
+                size = 14 + BitPaddedInt(fileobj.read(6)[2:])
+                fileobj.seek(size - 4)
+                if fileobj.read(4) != "fLaC": size = None
+        if size is None:
+            raise FLACNoHeaderError(
+                "%r is not a valid FLAC file" % fileobj.name)
+        return size
+
 Open = FLAC
 
 def delete(filename):
