@@ -5,7 +5,7 @@
 # it under the terms of version 2 of the GNU General Public License as
 # published by the Free Software Foundation.
 #
-# $Id: id3.py 3992 2007-01-27 01:40:51Z piman $
+# $Id: id3.py 4026 2007-04-27 02:13:05Z piman $
 
 """ID3v2 reading and writing.
 
@@ -35,7 +35,7 @@ from zlib import error as zlibError
 from warnings import warn
 
 import mutagen
-from mutagen._util import insert_bytes, delete_bytes
+from mutagen._util import insert_bytes, delete_bytes, DictProxy
 
 class error(Exception): pass
 class ID3NoHeaderError(error, ValueError): pass
@@ -51,7 +51,7 @@ class ID3Warning(error, UserWarning): pass
 def is_valid_frame_id(frame_id):
     return frame_id.isalnum() and frame_id.isupper()
 
-class ID3(mutagen.Metadata):
+class ID3(DictProxy, mutagen.Metadata):
     """A file with an ID3v2 tag.
 
     Attributes:
@@ -420,7 +420,7 @@ class ID3(mutagen.Metadata):
             date = str(self.pop("TYER"))
             if str(self.get("TDAT", "")).strip("\x00"):
                 dat = str(self.pop("TDAT"))
-                date = "%s-%s-%s" % (date, dat[:2], dat[2:])
+                date = "%s-%s-%s" % (date, dat[2:], dat[:2])
                 if str(self.get("TIME", "")).strip("\x00"):
                     time = str(self.pop("TIME"))
                     date += "T%s:%s:00" % (time[:2], time[2:])
@@ -1305,7 +1305,7 @@ class PairedTextFrame(Frame):
     Some ID3 frames pair text strings, to associate names with a more
     specific involvement in the song. The 'people' attribute of these
     frames contains a list of pairs:
-        [['trumpet', 'Miles Davis'], ['Paul Chambers', 'bass']]
+        [['trumpet', 'Miles Davis'], ['bass', 'Paul Chambers']]
 
     Like text frames, these frames also have an encoding attribute.
     """
