@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: m4a.py 3992 2007-01-27 01:40:51Z piman $
+# $Id: m4a.py 4026 2007-04-27 02:13:05Z piman $
 
 """Read and write MPEG-4 audio files with iTunes metadata.
 
@@ -29,7 +29,7 @@ from cStringIO import StringIO
 
 from mutagen import FileType, Metadata
 from mutagen._constants import GENRES
-from mutagen._util import cdata, insert_bytes, delete_bytes
+from mutagen._util import cdata, insert_bytes, delete_bytes, DictProxy
 
 class error(IOError): pass
 class M4AMetadataError(error): pass
@@ -172,7 +172,7 @@ class Atoms(object):
     def __repr__(self):
         return "\n".join([repr(child) for child in self.atoms])
 
-class M4ATags(Metadata):
+class M4ATags(DictProxy, Metadata):
     """Dictionary containing Apple iTunes metadata list key/values.
 
     Keys are four byte identifiers, except for freeform ('----')
