@@ -4,7 +4,7 @@
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: mp4.py 3992 2007-01-27 01:40:51Z piman $
+# $Id: mp4.py 4026 2007-04-27 02:13:05Z piman $
 
 """Read and write MPEG-4 audio files with iTunes metadata.
 
@@ -25,7 +25,7 @@ import sys
 
 from mutagen import FileType, Metadata
 from mutagen._constants import GENRES
-from mutagen._util import cdata, insert_bytes, delete_bytes
+from mutagen._util import cdata, insert_bytes, delete_bytes, DictProxy
 
 class error(IOError): pass
 class MP4MetadataError(error): pass
@@ -174,7 +174,7 @@ class Atoms(object):
     def __repr__(self):
         return "\n".join([repr(child) for child in self.atoms])
 
-class MP4Tags(Metadata):
+class MP4Tags(DictProxy, Metadata):
     """Dictionary containing Apple iTunes metadata list key/values.
 
     Keys are four byte identifiers, except for freeform ('----')
@@ -198,6 +198,15 @@ class MP4Tags(Metadata):
         'egid' -- podcast episode GUID
         'catg' -- podcast category
         'keyw' -- podcast keywords
+        '\xa9too' -- encoded by
+        'cprt' -- copyright
+        'soal' -- album sort order
+        'soaa' -- album artist sort order
+        'soar' -- artist sort order
+        'sonm' -- title sort order
+        'soco' -- composer sort order
+        'sosn' -- show sort order
+        'tvsh' -- show name
 
     Boolean values:
         'cpil' -- part of a compilation
