@@ -4,7 +4,12 @@ import shutil
 from cStringIO import StringIO
 from tempfile import mkstemp
 from tests import TestCase, add
-from mutagen.m4a import M4A, Atom, Atoms, M4ATags, M4AInfo, delete
+
+import warnings
+warnings.simplefilter("ignore", DeprecationWarning)
+from mutagen.m4a import M4A, Atom, Atoms, M4ATags, M4AInfo, \
+     delete, M4ACover, M4AMetadataError
+
 try: from os.path import devnull
 except ImportError: devnull = "/dev/null"
 
@@ -127,6 +132,11 @@ class TM4ATags(TestCase):
         tags = self.wrap_ilst(foob)
         self.failIf(tags)
 
+    def test_bad_covr(self):
+        data = Atom.render("foob", "\x00\x00\x00\x0E" + "\x00" * 4 + "whee")
+        covr = Atom.render("covr", data)
+        self.failUnlessRaises(M4AMetadataError, self.wrap_ilst, covr)
+
 add(TM4ATags)
 
 class TM4A(TestCase):
@@ -200,6 +210,12 @@ class TM4A(TestCase):
     def test_cover(self):
         self.set_key('covr', 'woooo')
 
+    def test_cover_png(self):
+        self.set_key('covr', M4ACover('woooo', M4ACover.FORMAT_PNG))
+
+    def test_cover_jpeg(self):
+        self.set_key('covr', M4ACover('hoooo', M4ACover.FORMAT_JPEG))
+
     def test_pprint(self):
         self.audio.pprint()
 
@@ -222,6 +238,9 @@ class TM4A(TestCase):
     def test_reads_unknown_text(self):
         self.set_key("foob", u"A test")
 
+    def test_mime(self):
+        self.failUnless("audio/mp4" in self.audio.mime)
+
     def tearDown(self):
         os.unlink(self.filename)
 
@@ -241,6 +260,11 @@ class TM4AHasTags(TM4A):
     def test_has_tags(self):
         self.failUnless(self.audio.tags)
 
+    def test_has_covr(self):
+        self.failUnless('covr' in self.audio.tags)
+        covr = self.audio.tags['covr']
+        self.failUnlessEqual(covr.format, M4ACover.FORMAT_PNG)
+
     def test_not_my_file(self):
         self.failUnlessRaises(
             IOError, M4A, os.path.join("tests", "data", "empty.ogg"))
